==> telepathy-glib-0.17.5.tar.gz: telepathy-glib-0.17.5/telepathy-glib/automatic-client-factory-internal.h <==
/*
 * Internal constructors for TpChannel subclasses
 *
 * Copyright © 2011 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TP_AUTOMATIC_CLIENT_FACTORY_INTERNAL_H__
#define __TP_AUTOMATIC_CLIENT_FACTORY_INTERNAL_H__

#include <telepathy-glib/automatic-client-factory.h>

G_BEGIN_DECLS

TpTextChannel *_tp_text_channel_new_with_factory (
    TpSimpleClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    const GHashTable *immutable_properties,
    GError **error);

TpStreamTubeChannel *_tp_stream_tube_channel_new_with_factory (
    TpSimpleClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    const GHashTable *immutable_properties,
    GError **error);

TpDBusTubeChannel *_tp_dbus_tube_channel_new_with_factory (
    TpSimpleClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    const GHashTable *immutable_properties,
    GError **error);

TpFileTransferChannel *_tp_file_transfer_channel_new_with_factory (
    TpSimpleClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    const GHashTable *immutable_properties,
    GError **error);

TpCallChannel *_tp_call_channel_new_with_factory (
    TpSimpleClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    const GHashTable *immutable_properties,
    GError **error);

G_END_DECLS

#endif

==> telepathy-glib-0.99.11.tar.gz: telepathy-glib-0.99.11/telepathy-glib/automatic-client-factory-internal.h <==
/*<private_header>*/
/*
 * Internal constructors for TpChannel subclasses
 *
 * Copyright © 2011 Collabora Ltd.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TP_AUTOMATIC_CLIENT_FACTORY_INTERNAL_H__
#define __TP_AUTOMATIC_CLIENT_FACTORY_INTERNAL_H__

#include <telepathy-glib/automatic-client-factory.h>

G_BEGIN_DECLS

TpTextChannel *_tp_text_channel_new (TpClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    GVariant *immutable_properties,
    GError **error);

TpStreamTubeChannel *_tp_stream_tube_channel_new (TpClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    GVariant *immutable_properties,
    GError **error);

TpDBusTubeChannel *_tp_dbus_tube_channel_new (TpClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    GVariant *immutable_properties,
    GError **error);

TpFileTransferChannel *_tp_file_transfer_channel_new (TpClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    GVariant *immutable_properties,
    GError **error);

TpCallChannel *_tp_call_channel_new (TpClientFactory *factory,
    TpConnection *conn,
    const gchar *object_path,
    GVariant *immutable_properties,
    GError **error);

G_END_DECLS

#endif
